import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import _objectWithoutProperties from '@babel/runtime/helpers/esm/objectWithoutProperties';
import { useSlotId } from '@react-aria/utils';
import { useRef, useMemo } from 'react';
import { checkCircle2Icon } from '@voussoir/icon/icons/checkCircle2Icon';
import { infoIcon } from '@voussoir/icon/icons/infoIcon';
import { alertTriangleIcon } from '@voussoir/icon/icons/alertTriangleIcon';
import { Icon } from '@voussoir/icon';
import { Grid, minmax } from '@voussoir/layout';
import { SlotProvider, Content } from '@voussoir/slots';
import { useHasChild, filterDOMProps, isReactText } from '@voussoir/utils';
import { useStyleProps, css, tokenSchema } from '@voussoir/style';
import { Text } from '@voussoir/typography';
import { jsxs, jsx } from 'react/jsx-runtime';

var _excluded = ["children", "tone"];
var toneToIcon = {
  caution: alertTriangleIcon,
  critical: alertTriangleIcon,
  neutral: infoIcon,
  positive: checkCircle2Icon
};
var toneToRole = {
  caution: 'alert',
  critical: 'alert',
  neutral: 'status',
  positive: 'status'
};
/**
 * Use notices to highlight information that affects a section, feature or page.
 * Draw attention without interrupting users from their current task.
 */
function Notice(props) {
  var children = props.children,
    _props$tone = props.tone,
    tone = _props$tone === void 0 ? 'neutral' : _props$tone,
    otherProps = _objectWithoutProperties(props, _excluded);
  var ref = useRef(null);
  var styleProps = useStyleProps(otherProps);
  var headingId = useSlotId();
  var contentId = useSlotId();
  var hasHeading = useHasChild("#".concat(headingId), ref);
  var coercedTone = tone === 'neutral' ? 'accent' : tone;
  var icon = toneToIcon[tone];
  var contentStyles = css({
    display: 'grid',
    gap: tokenSchema.size.space.large
  });
  var slots = useMemo(function () {
    return {
      content: {
        elementType: 'div',
        gridArea: hasHeading ? 'content' : 'heading-start / heading-start / content-end / content-end',
        id: contentId,
        paddingY: hasHeading ? 'regular' : undefined,
        UNSAFE_className: contentStyles
      },
      heading: {
        elementType: 'div',
        gridArea: 'heading',
        id: headingId,
        size: 'small'
      },
      text: {
        color: coercedTone,
        weight: 'medium'
      }
    };
  }, [coercedTone, contentId, contentStyles, hasHeading, headingId]);
  return /*#__PURE__*/jsxs(Grid, _objectSpread(_objectSpread({
    "aria-live": "polite",
    "aria-labelledby": headingId,
    "aria-describedby": contentId,
    role: toneToRole[tone],
    ref: ref,
    tabIndex: 0,
    UNSAFE_className: styleProps.className,
    UNSAFE_style: styleProps.style
  }, filterDOMProps(otherProps)), {}, {
    // appearance
    backgroundColor: coercedTone,
    border: coercedTone,
    borderRadius: "medium",
    minWidth: 0,
    padding: "medium",
    width: "100%"
    // layout
    ,
    alignItems: "center",
    areas: ['icon heading', 'icon content'],
    columnGap: "medium",
    columns: ['size.icon.medium', 'auto'],
    rows: [minmax('size.icon.medium', 'auto'), 'auto'],
    children: [/*#__PURE__*/jsx(Icon, {
      src: icon,
      size: "medium",
      color: coercedTone,
      gridArea: "icon",
      alignSelf: "start"
    }), /*#__PURE__*/jsx(SlotProvider, {
      slots: slots,
      children: isReactText(children) ? /*#__PURE__*/jsx(Content, {
        children: /*#__PURE__*/jsx(Text, {
          children: children
        })
      }) : children
    })]
  }));
}

export { Notice };
